@@ -18,4 +18,11 @@ class IdentityManager(base.BaseManager):
 
     # PROXY
     users = UserManager()
-    auth = AuthManager()
\ No newline at end of file
+    auth = AuthManager()
+
+    def switch_location(self, request, data):
+        return self.request(
+            request,
+            '/{0}/location/switch/'.format(self.SCOPE),
+            'POST',
+            data)
\ No newline at end of file
